# from django import forms
# from django.utils.translation import gettext_lazy as _
# from utilities.forms import BootstrapMixin, StaticSelect
from netbox.forms import NetBoxModelForm
from .models import Settings


class SettingsForm(NetBoxModelForm):
    class Meta:
        model = Settings
        fields = [
            "hostname",
            "username",
            "password",
            "version",
            "verify",
            "status",
        ]



from django.contrib import admin
from .models import Settings

""" Admin view for Settings """


@admin.register(Settings)
class CiscoDNACNetBoxAdmin(admin.ModelAdmin):
    list_display = ("hostname", "username", "status")



from extras.plugins import PluginConfig
from .metadata import App


class CiscoDNACenterConfig(PluginConfig):
    version = App._VERSION_
    name = App._NAME_
    verbose_name = "Cisco DNA Center Sync Plugin"
    description = App._DESC_
    author = App._AUTHOR_
    author_email = App._EMAIL_
    required_settings = []
    default_settings = {}
    base_url = App._NAME_
    caching_config = {}


config = CiscoDNACenterConfig



import django_tables2 as tables
from django_tables2.utils import A
from django.utils.safestring import mark_safe
from netbox.tables import NetBoxTable, columns
from .models import Settings


class MaskedPassword(tables.Column):
    def render(self, value):
        value = "*****"
        return mark_safe(value)


class SettingsTable(NetBoxTable):
    pk = columns.ToggleColumn()
    hostname = tables.LinkColumn(
        "plugins:ciscodnacnetbox:settings_edit", args=[A("pk")]
    )
    username = tables.Column()
    password = MaskedPassword()
    version = tables.Column()
    verify = columns.BooleanColumn()
    status = columns.BooleanColumn()

    class Meta(NetBoxTable.Meta):
        model = Settings
        fields = [
            "pk",
            "hostname",
            "username",
            "password",
            "version",
            "verify",
            "status",
        ]



class App:
    _NAME_ = "ciscodnacnetbox"
    _VERSION_ = "3.2.1"
    _DESC_ = "Cisco DNA Center Integration with NetBox"
    _AUTHOR_ = "Robert Csapo"
    _EMAIL_ = "rcsapo@cisco.com"
    _URL_ = "https://github.com/robertcsapo/ciscodnacnetbox"
